@@ -7,6 +7,7 @@ pass the names of specific files to format instead.
 import argparse
 import functools
 import multiprocessing
+import os
 import subprocess
 import sys
 import warnings
@@ -27,7 +28,7 @@ def _guess_first_party_modules(cwd: str = None) -> FrozenSet[str]:
             check=True,
             timeout=10,
             stdout=subprocess.PIPE,
-            universal_newlines=True,
+            text=True,
             cwd=cwd,
         ).stdout.strip()
     except (subprocess.SubprocessError, FileNotFoundError):
@@ -57,6 +58,8 @@ def _rewrite_on_disk(
         with warnings.catch_warnings(record=True) as record:
             result = writer(on_disk, _location=f"file {fname!r}", **kwargs)
     except Exception as err:  # pragma: no cover  # bugs are unknown xor fixed ;-)
+        if "SHED_RAISE" in os.environ:
+            raise
         return (
             f"Internal error formatting {fname!r}: {type(err).__name__}: {err}\n"
             "    Please report this to https://github.com/Zac-HD/shed/issues"
@@ -111,7 +114,7 @@ def cli() -> None:  # pragma: no cover  # mutates things in-place, will test lat
                 check=True,
                 timeout=10,
                 stdout=subprocess.PIPE,
-                universal_newlines=True,
+                text=True,
             ).stdout.splitlines()
         except (subprocess.SubprocessError, FileNotFoundError):
             print("Doesn't seem to be a git repo; pass filenames to format.")  # noqa
